"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScanService = void 0;
var context_map_server_client_1 = require("../infrastructure/client/context-map-server.client");
var scan_1 = require("../model/scan");
var resource_service_1 = require("./resource.service");
var technology_stack_service_1 = require("./technology-stack.service");
var decorator_service_1 = require("./decorator.service");
var actor_service_1 = require("./actor.service");
var ts_morph_1 = require("ts-morph");
var subscribed_endpoint_service_1 = require("./subscribed-endpoint.service");
var ScanService = /** @class */ (function () {
    function ScanService(parameters) {
        this.parameters = parameters;
        this.project = new ts_morph_1.Project();
        this.client = new context_map_server_client_1.ContextMapServerClient(parameters);
        this.resourceService = new resource_service_1.ResourceService();
        this.technologyStackService = new technology_stack_service_1.TechnologyStackService();
        this.decoratorService = new decorator_service_1.DecoratorService(this.project);
        this.actorService = new actor_service_1.ActorService(this.project);
        this.subscribedEndpointService = new subscribed_endpoint_service_1.SubscribedEndpointService(this.project);
    }
    ScanService.prototype.scan = function () {
        var scan = this.initializeScan();
        this.scanConfiguration(scan);
        this.scanTechStack(scan);
        this.scanActors(scan);
        this.scanSubscribedEndpoints(scan);
        // this.scanDecorators(scan)
        this.sendScan(scan);
    };
    ScanService.prototype.initializeScan = function () {
        this.project.addSourceFilesAtPaths("src/**/*{.js,.ts}"); // TODO allow this parameter to be configured in case other location/files are needed
        return (0, scan_1.createScan)();
    };
    ScanService.prototype.scanConfiguration = function (scan) {
        var configurationResource = this.resourceService.scanConfiguration();
        scan.execution.scannedProperties = true;
        scan.execution.scannedSystem = true;
        scan.scannedComponent.name = configurationResource.getName();
        scan.scannedComponent.version = configurationResource.getVersion();
        scan.scannedComponent.team = configurationResource.getTeam();
        scan.scannedComponent.domainVisionStatement = configurationResource.getDomainVisionStatement();
        scan.scannedComponent.systemName = configurationResource.getSystemName();
        scan.scannedComponent.type = configurationResource.getComponentType();
    };
    ScanService.prototype.scanDecorators = function (scan) {
        console.info("Scanning entities");
        scan.execution.scannedEntities = true;
        scan.entities = this.decoratorService.scan();
        console.info(" < Found " + scan.entities.length + " entities");
    };
    ScanService.prototype.scanSubscribedEndpoints = function (scan) {
        console.info("Scanning subscribed endpoints");
        scan.execution.scannedSubscribedEndpoints = true;
        scan.subscribedEndpoints = this.subscribedEndpointService.scan();
        console.info(" < Found " + scan.subscribedEndpoints.length + " subscribed endpoints");
    };
    ScanService.prototype.scanActors = function (scan) {
        console.info("Scanning actors");
        scan.execution.scannedActors = true;
        scan.actors = this.actorService.scan();
        console.info(" < Found " + scan.actors.length + " actors");
    };
    ScanService.prototype.scanTechStack = function (scan) {
        console.info("Scanning techstack");
        scan.execution.scannedTechnologies = true;
        scan.scannedComponent.technologies = this.technologyStackService.scan();
        console.info(" < Found " + scan.scannedComponent.technologies.length + " technologies");
    };
    ScanService.prototype.sendScan = function (scan) {
        return this.client.processScan(scan);
    };
    return ScanService;
}());
exports.ScanService = ScanService;
